Page 21 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 21

Home

    They are turned back to the iniquities of their
    forefathers, which refused to hear my words; and they
    went after other gods to serve them: .. .

    The Old Testament prophet Ezekiel also lamented
    such a movement in Israel:

    There is a conspiracy of her prophets in the midst
    thereof, like a roaring lion ravening the prey; they have
    devoured souls; they have taken the treasure and
    precious things; they have made her many widows in the
    midst thereof.

    These conspiracies so corrupted Judah and Israel that
    the two nations were conquered, and their people taken
    away into slavery by Assyria and Babylon.

    Intellectuals often scoff at the mention of conspiracy,
    but it is impossible to believe the Scriptures and not

    believe in conspiracies. Conspiracies are mentioned
    thirty times in the Old Testament, often in connection
    with the overthrow, or attempted overthrow, of existing

    governments.

    The existence of secret oral traditions among the Jews
    could well explain some of the language of the New
    Testament. In John 7:49 for example, the Pharisees said,
    "But this people who knoweth not the law are cursed."
    Yet, the people did know the written law. At this time in
    the history of the Jews, the Law was revered by the
    common people and regularly read to them in the

    16

    The Secret Side of History

    Ezekiel 22:25